# Queue management

Playback queue lets you manually control playlist contents for the forseeable future. You add as many as you want individual tracks to the queue, ardj plays them. When the queue is empty, it goes back to automatic mode.

You can add "pause" to the queuee, to let ardj play an automatically scheduled track, then get back to your queue.

## Control the queue using console

    $ ardj console
    > find дом
    «Песня идущего домой» by Ю-Питер — #6899 ⚖1.00 ♺0
    > queue 6899